@@ -3,7 +3,6 @@ from __future__ import annotations
 # standard libraries
 import abc
 import asyncio
-import collections
 import copy
 import datetime
 import gettext
@@ -595,7 +594,7 @@ class Mask:
             graphic = Graphics.factory(lambda t: graphic_dict["type"])
             graphic.read_from_mime_data(graphic_dict)
             if graphic:
-                part_mask = graphic.get_mask(data_shape).astype(numpy.bool)
+                part_mask = graphic.get_mask(data_shape).astype(bool)
                 if inverted:
                     part_mask = numpy.logical_not(part_mask)
                 if value == "grad_x":
