@@ -29,19 +29,20 @@ _ = gettext.gettext
 
 class CameraAcquisitionTask(HardwareSource.AcquisitionTask):
 
-    def __init__(self, stem_controller, hardware_source_id, is_continuous: bool, camera, camera_category: str, frame_parameters, display_name):
+    def __init__(self, stem_controller, hardware_source_id, is_continuous: bool, camera, camera_category: str, signal_type: typing.Optional[str], frame_parameters, display_name):
         super().__init__(is_continuous)
         self.__stem_controller = stem_controller
         self.hardware_source_id = hardware_source_id
         self.is_continuous = is_continuous
         self.__camera = camera
         self.__camera_category = camera_category
+        self.__signal_type = signal_type
         self.__display_name = display_name
         self.__frame_parameters = None
-        self.__pending_frame_parameters = copy.copy(frame_parameters)
+        self.__pending_frame_parameters = CameraFrameParameters(frame_parameters)
 
     def set_frame_parameters(self, frame_parameters):
-        self.__pending_frame_parameters = copy.copy(frame_parameters)
+        self.__pending_frame_parameters = CameraFrameParameters(frame_parameters)
 
     @property
     def frame_parameters(self):
@@ -105,8 +106,8 @@ class CameraAcquisitionTask(HardwareSource.AcquisitionTask):
         data_element["properties"]["valid_rows"] = cumulative_data.shape[0]
         data_element["properties"]["frame_index"] = data_element["properties"]["frame_number"]
         data_element["properties"]["integration_count"] = cumulative_frame_count
-        if self.__camera_category in ("eels", "ronchigram"):
-            data_element["properties"]["signal_type"] = self.__camera_category
+        if self.__signal_type:
+            data_element["properties"]["signal_type"] = self.__signal_type
         return [data_element]
 
     def __activate_frame_parameters(self):
@@ -131,6 +132,9 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
         self.__camera = camera
         self.__camera_category = camera.camera_type
         self.modes = ["Run", "Tune", "Snap"]
+        # signal type falls back to camera category if camera category is "eels" or "ronchigram". this is only for
+        # backward compatibility. new camera instances should define signal_type directly.
+        self.__signal_type = getattr(camera, "signal_type", self.__camera_category if self.__camera_category in ("eels", "ronchigram") else None)
         self.processor = None
 
         # configure the features
@@ -144,6 +148,9 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
         if self.__camera_category.lower() == "eels":
             self.features["is_eels_camera"] = True
             self.processor = HardwareSource.SumProcessor(((0.25, 0.0), (0.5, 1.0)))
+        self.features["has_processed_channel"] = self.processor is not None
+        # future version will also include the processed channel type;
+        # candidates for the official name are "vertical_sum" or "vertical_projection_profile"
 
         # on_low_level_parameter_changed is handled for backwards compatibility (old DLLs with new hardware source).
         # new DLLs should call on_mode_changed and on_mode_parameter_changed (handled below) and should NOT call
@@ -197,8 +204,8 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
         self.__profiles = list()
         self.__profiles.extend(self.__get_initial_profiles())
         self.__current_profile_index = self.__get_initial_profile_index()
-        self.__frame_parameters = self.__profiles[0]
-        self.__record_parameters = self.__profiles[2]
+        self.__frame_parameters = CameraFrameParameters(self.__profiles[0])
+        self.__record_parameters = CameraFrameParameters(self.__profiles[2])
 
         self.__acquisition_task = None
 
@@ -274,6 +281,33 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
             if len(messages) > 0 or len(data_elements) > 0:
                 self.log_messages_event.fire(messages, data_elements)
 
+    def start_playing(self, *args, **kwargs):
+        if "frame_parameters" in kwargs:
+            self.set_current_frame_parameters(kwargs["frame_parameters"])
+        elif len(args) == 1 and isinstance(args[0], dict):
+            self.set_current_frame_parameters(args[0])
+        super().start_playing(*args, **kwargs)
+
+    def grab_next_to_start(self, *, timeout: float=None, **kwargs) -> typing.List[DataAndMetadata.DataAndMetadata]:
+        self.start_playing()
+        return self.get_next_xdatas_to_start(timeout)
+
+    def grab_next_to_finish(self, *, timeout: float=None, **kwargs) -> typing.List[DataAndMetadata.DataAndMetadata]:
+        self.start_playing()
+        return self.get_next_xdatas_to_finish(timeout)
+
+    def grab_sequence_prepare(self, count: int, **kwargs) -> bool:
+        return False
+
+    def grab_sequence(self, count: int, **kwargs) -> typing.Optional[typing.List[DataAndMetadata.DataAndMetadata]]:
+        return None
+
+    def grab_sequence_abort(self) -> None:
+        return None
+
+    def grab_sequence_get_progress(self) -> typing.Optional[float]:
+        return None
+
     @property
     def camera(self):
         return self.__camera
@@ -299,14 +333,20 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
 
     def _create_acquisition_view_task(self) -> HardwareSource.AcquisitionTask:
         assert self.__frame_parameters is not None
-        return CameraAcquisitionTask(self.__get_stem_controller(), self.hardware_source_id, True, self.__camera, self.__camera_category, self.__frame_parameters, self.display_name)
+        return CameraAcquisitionTask(self.__get_stem_controller(), self.hardware_source_id, True, self.__camera, self.__camera_category, self.__signal_type, self.__frame_parameters, self.display_name)
 
     def _view_task_updated(self, view_task):
         self.__acquisition_task = view_task
 
     def _create_acquisition_record_task(self) -> HardwareSource.AcquisitionTask:
         assert self.__record_parameters is not None
-        return CameraAcquisitionTask(self.__get_stem_controller(), self.hardware_source_id, False, self.__camera, self.__camera_category, self.__record_parameters, self.display_name)
+        return CameraAcquisitionTask(self.__get_stem_controller(), self.hardware_source_id, False, self.__camera, self.__camera_category, self.__signal_type, self.__record_parameters, self.display_name)
+
+    def acquire_synchronized_prepare(self, data_shape, **kwargs) -> None:
+        self.acquire_sequence_prepare(int(numpy.product(data_shape)))
+
+    def acquire_synchronized(self, data_shape, **kwargs) -> typing.Sequence[typing.Dict]:
+        return self.acquire_sequence(int(numpy.product(data_shape)))
 
     def acquire_sequence_prepare(self, n: int) -> None:
         frame_parameters = self.get_current_frame_parameters()
@@ -323,7 +363,7 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
                 return data_element
         # if the device does not implement acquire_sequence, fall back to looping acquisition.
         processing = frame_parameters.processing
-        acquisition_task = CameraAcquisitionTask(self.__get_stem_controller(), self.hardware_source_id, True, self.__camera, self.__camera_category, frame_parameters, self.display_name)
+        acquisition_task = CameraAcquisitionTask(self.__get_stem_controller(), self.hardware_source_id, True, self.__camera, self.__camera_category, self.__signal_type, frame_parameters, self.display_name)
         acquisition_task._start_acquisition()
         try:
             properties = None
@@ -377,7 +417,7 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
         return dict()
 
     def set_frame_parameters(self, profile_index, frame_parameters):
-        frame_parameters = copy.copy(frame_parameters)
+        frame_parameters = CameraFrameParameters(frame_parameters)
         self.__profiles[profile_index] = frame_parameters
         # update the frame parameters on the device
         mode_id = self.modes[profile_index]
@@ -391,18 +431,18 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
         self.frame_parameters_changed_event.fire(profile_index, frame_parameters)
 
     def get_frame_parameters(self, profile_index):
-        return copy.copy(self.__profiles[profile_index])
+        return CameraFrameParameters(self.__profiles[profile_index])
 
     def set_current_frame_parameters(self, frame_parameters):
         if self.__acquisition_task:
             self.__acquisition_task.set_frame_parameters(frame_parameters)
-        self.__frame_parameters = copy.copy(frame_parameters)
+        self.__frame_parameters = CameraFrameParameters(frame_parameters)
 
     def get_current_frame_parameters(self):
-        return self.__frame_parameters
+        return CameraFrameParameters(self.__frame_parameters)
 
     def set_record_frame_parameters(self, frame_parameters):
-        self.__record_parameters = copy.copy(frame_parameters)
+        self.__record_parameters = CameraFrameParameters(frame_parameters)
 
     def get_record_frame_parameters(self):
         return self.__record_parameters
@@ -471,24 +511,24 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
     def open_monitor(self):
         self.__camera.start_monitor()
 
-    def shift_click(self, mouse_position, camera_shape):
+    def shift_click(self, mouse_position, camera_shape, logger: logging.Logger) -> None:
         if self.__camera_category.lower() == "ronchigram":
             stem_controller = self.__get_stem_controller()
             radians_per_pixel = stem_controller.get_value("TVPixelAngle")
             defocus_value = stem_controller.get_value("C10")  # get the defocus
             dx = radians_per_pixel * defocus_value * (mouse_position[1] - (camera_shape[1] / 2))
             dy = radians_per_pixel * defocus_value * (mouse_position[0] - (camera_shape[0] / 2))
-            logging.info("Shifting (%s,%s) um.\n", dx * 1e6, dy * 1e6)
+            logger.info("Shifting (%s,%s) um.\n", dx * 1e6, dy * 1e6)
             stem_controller.set_value("SShft.x", stem_controller.get_value("SShft.x") - dx)
             stem_controller.set_value("SShft.y", stem_controller.get_value("SShft.y") - dy)
 
-    def tilt_click(self, mouse_position, camera_shape):
+    def tilt_click(self, mouse_position, camera_shape, logger: logging.Logger) -> None:
         if self.__camera_category.lower() == "ronchigram":
             stem_controller = self.__get_stem_controller()
             radians_per_pixel = stem_controller.get_value("TVPixelAngle")
             da = radians_per_pixel * (mouse_position[1] - (camera_shape[1] / 2))
             db = radians_per_pixel * (mouse_position[0] - (camera_shape[0] / 2))
-            logging.info("Tilting (%s,%s) rad.\n", da, db)
+            logger.info("Tilting (%s,%s) rad.\n", da, db)
             stem_controller.set_value("STilt.x", stem_controller.get_value("STilt.x") - da)
             stem_controller.set_value("STilt.y", stem_controller.get_value("STilt.y") - db)
 
@@ -503,7 +543,7 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
         if Utility.compare_versions(version, actual_version) > 0:
             raise NotImplementedError("Camera API requested version %s is greater than %s." % (version, actual_version))
 
-        class CameraFacade(object):
+        class CameraFacade:
 
             def __init__(self):
                 pass
@@ -511,14 +551,23 @@ class CameraHardwareSource(HardwareSource.HardwareSource):
         return CameraFacade()
 
 
-class CameraFrameParameters(object):
+class CameraFrameParameters(dict):
 
-    def __init__(self, d=None):
-        d = d or dict()
-        self.exposure_ms = d.get("exposure_ms", 125)
-        self.binning = d.get("binning", 1)
-        self.processing = d.get("processing")
-        self.integration_count = d.get("integration_count")
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.__dict__ = self
+        self.exposure_ms = self.get("exposure_ms", 125)
+        self.binning = self.get("binning", 1)
+        self.processing = self.get("processing")
+        self.integration_count = self.get("integration_count")
+
+    def __copy__(self):
+        return self.__class__(copy.copy(dict(self)))
+
+    def __deepcopy__(self, memo):
+        deepcopy = self.__class__(copy.deepcopy(dict(self)))
+        memo[id(self)] = deepcopy
+        return deepcopy
 
     def as_dict(self):
         return {
